@@ -2,7 +2,7 @@ package Config::IniFiles;
 
 use vars qw($VERSION);
 
-$VERSION = '2.78';
+$VERSION = '2.79';
 
 require 5.004;
 use strict;
@@ -255,7 +255,7 @@ syntax.
 
 =item I<-allowempty> 0|1
 
-If set to 1, then empty files are allowed at L</ReadConfig|ReadConfig()>
+If set to 1, then empty files are allowed at L<ReadConfig|ReadConfig()>
 time. If set to 0 (the default), an empty configuration file is considered
 an error.
 
@@ -276,7 +276,7 @@ or
 If set to 0 (the default if not importing), these comments are treated
 like ordinary ones.
 
-The L</WriteConfig|WriteConfig($filename, -delta=>1)> form will output such
+The L<WriteConfig|WriteConfig($filename, -delta=>1)> form will output such
 comments to indicate deleted sections or parameters. This way,
 reloading a delta file using the same imported object produces the
 same results in memory again. See L<IMPORT / DELTA FEATURES> for more
